@@ -21,7 +21,7 @@ unless (defined $Test::Deep::NoTest::NoTest)
 
 our ($Stack, %Compared, $CompareCache, %WrapCache, $Shallow);
 
-our $VERSION = '1.126_001';
+our $VERSION = '1.122';
 $VERSION =~ tr/_//d;
 
 require Exporter;
@@ -91,7 +91,7 @@ while (my ($pkg, $name) = splice @constructors, 0, 2)
 }
 
 {
-  our @EXPORT_OK = qw( descend render_stack cmp_details deep_diag );
+  our @EXPORT_OK = qw( descend render_stack class_base cmp_details deep_diag );
 
   our %EXPORT_TAGS;
   $EXPORT_TAGS{preload} = [];
@@ -413,20 +413,13 @@ sub wrap
 {
   my $data = shift;
 
-  my $class = Scalar::Util::blessed($data);
-  return $data if defined $class and $data->isa("Test::Deep::Cmp");
+  return $data if Scalar::Util::blessed($data) and $data->isa("Test::Deep::Cmp");
 
-  if (defined $class and $data->can('as_test_deep_cmp')) {
-    my $cmp = $data->as_test_deep_cmp;
-    return $cmp if $cmp->isa('Test::Deep::Cmp');
-    Carp::confess("object in expected structure provides as_test_deep_cmp but it did not return a Test::Deep::Cmp");
-  }
-
-  my $reftype = _td_reftype($data);
+  my ($class, $base) = class_base($data);
 
   my $cmp;
 
-  if($reftype eq '')
+  if($base eq '')
   {
     $cmp = $Test::Deep::LeafWrapper
          ? $Test::Deep::LeafWrapper->($data)
@@ -438,27 +431,25 @@ sub wrap
 
     return $WrapCache{$addr} if $WrapCache{$addr};
 
-    if($reftype eq 'ARRAY')
+    if($base eq 'ARRAY')
     {
       $cmp = array($data);
     }
-    elsif($reftype eq 'HASH')
+    elsif($base eq 'HASH')
     {
       $cmp = hash($data);
     }
-    elsif($reftype eq 'SCALAR' or $reftype eq 'REF')
+    elsif($base eq 'SCALAR' or $base eq 'REF')
     {
       $cmp = scalref($data);
     }
-    elsif(($reftype eq 'Regexp') or ($reftype eq 'REGEXP'))
+    elsif(($base eq 'Regexp') or ($base eq 'REGEXP'))
     {
       $cmp = regexpref($data);
     }
     else
     {
-      $cmp = $Test::Deep::LeafWrapper
-           ? $Test::Deep::LeafWrapper->($data)
-           : shallow($data);
+      $cmp = shallow($data);
     }
 
     $WrapCache{$addr} = $cmp;
@@ -466,24 +457,29 @@ sub wrap
   return $cmp;
 }
 
-sub _td_reftype
+sub class_base
 {
   my $val = shift;
 
-  my $reftype = Scalar::Util::reftype($val);
-  return '' unless defined $reftype;
-
-  return $reftype unless $Test::Deep::RegexpVersion::OldStyle;
-
-  my $blessed = Scalar::Util::blessed($val);
-  return $reftype unless defined $blessed;
-
-  if ($blessed && $blessed eq "Regexp" and $reftype eq "SCALAR")
+  if (ref $val)
   {
-    $reftype = "Regexp"
-  }
+    my $blessed = Scalar::Util::blessed($val);
+    $blessed = defined($blessed) ? $blessed : "";
+    my $reftype = Scalar::Util::reftype($val);
 
-  return $reftype;
+
+    if ($Test::Deep::RegexpVersion::OldStyle) {
+      if ($blessed eq "Regexp" and $reftype eq "SCALAR")
+      {
+        $reftype = "Regexp"
+      }
+    }
+    return ($blessed, $reftype);
+  }
+  else
+  {
+    return ("", "");
+  }
 }
 
 sub render_stack
